package com.steerinfo.dil.controller;

import com.steerinfo.dil.service.impl.RmsMaterialServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/10/22 17:34
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/rmsmaterial")
public class RmsMaterialController extends BaseRESTfulController {

    @Autowired
    RmsMaterialServiceImpl rmsMaterialService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 物资管理对接接口
     *
     * @param mapVal
     * @return
     */
    @ApiModelProperty(value = "物资管理对接接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "EASMaterialId", value = "1", required = true, dataType = "Integer"),
            @ApiImplicitParam(name = "materialCode", value = "08010102010300005", required = true, dataType = "String"),
            @ApiImplicitParam(name = "materialType", value = "原料", required = true, dataType = "String"),
            @ApiImplicitParam(name = "materialName", value = "巴粉", required = true, dataType = "String"),
            @ApiImplicitParam(name = "materialSpecification", value = "", required = true, dataType = "String"),
            @ApiImplicitParam(name = "materialModel", value = "", required = true, dataType = "String"),
            @ApiImplicitParam(name = "unitOfMeasure", value = "吨", required = true, dataType = "String"),
            @ApiImplicitParam(name = "materialLength", value = "", required = true, dataType = "Double"),
            @ApiImplicitParam(name = "dataStatus", value = "1", required = true, dataType = "Integer"),
    })
    @PostMapping("/operationMaterial")
    public RESTfulResult operationMaterial(@RequestBody Map<String, Object> mapVal) {
        int result = rmsMaterialService.operationMaterial(mapVal);
        return success(result);
    }

    /**
     * 展示物资信息
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示物资信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "196", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getMaterialList")
    public RESTfulResult getMaterialList(@RequestBody(required = false) Map<String,Object> mapVal,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer apiId){
        List<Map<String,Object>> list = rmsMaterialService.getMaterialList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsMaterialService.getMaterialList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }


}
