package com.steerinfo.dil.controller;

import com.steerinfo.dil.service.impl.RmsSupplierServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/10/23 17:34
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/rmssupplier")
public class RmsSupplierController extends BaseRESTfulController {

    @Autowired
    RmsSupplierServiceImpl rmsSupplierService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 供应商管理对接接口
     *
     * @param mapVal
     * @return
     */
    @ApiModelProperty(value = "供应商管理对接接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "EASSupplierId", value = "1", required = true, dataType = "Integer"),
            @ApiImplicitParam(name = "supplierName", value = "四川美立达矿业有限责任公司", required = true, dataType = "String"),
            @ApiImplicitParam(name = "supplierAbbreviation", value = "四川美立达", required = true, dataType = "String"),
            @ApiImplicitParam(name = "supplierDutyParagraph", value = "SCMLD20211027", required = true, dataType = "String"),
            @ApiImplicitParam(name = "supplierAddress", value = "四川省达州市通川区金龙大道119号", required = true, dataType = "String"),
            @ApiImplicitParam(name = "supplierRegisterDate", value = "2021-10-09 14:10:34", required = true, dataType = "Date"),
            @ApiImplicitParam(name = "supplierAgent", value = "李四", required = true, dataType = "String"),
            @ApiImplicitParam(name = "supplierContactNumber", value = "17356241456", required = true, dataType = "String"),
            @ApiImplicitParam(name = "dataStatus", value = "1", required = true, dataType = "Integer"),
    })
    @PostMapping("/operationSupplier")
    public RESTfulResult operationSupplier(@RequestBody Map<String, Object> mapVal) {
        int result = rmsSupplierService.operationSupplier(mapVal);
        return success(result);
    }

    /**
     * 展示供应商信息
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示供应商信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "198", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getSupplierList")
    public RESTfulResult getSupplierList(@RequestBody(required = false) Map<String,Object> mapVal,
                                                      Integer pageNum,
                                                      Integer pageSize,
                                                      Integer apiId){
        List<Map<String,Object>> list = rmsSupplierService.getSupplierList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsSupplierService.getSupplierList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }


}
